@@ -1,3 +1,4 @@
+import uuid
 from collections.abc import AsyncIterator, Callable
 from contextlib import AsyncExitStack, aclosing, asynccontextmanager
 from functools import lru_cache
@@ -13,6 +14,7 @@ from langchain_core.messages import (
     convert_to_messages,
     message_chunk_to_message,
 )
+from langchain_core.runnables import RunnableConfig
 from langgraph.errors import (
     EmptyChannelError,
     EmptyInputError,
@@ -93,21 +95,23 @@ def _preproces_debug_checkpoint_task(task: dict[str, Any]) -> dict[str, Any]:
     return task
 
 
-def _preprocess_debug_checkpoint(payload: CheckpointPayload | None) -> dict[str, Any]:
+def _preprocess_debug_checkpoint(
+    payload: CheckpointPayload | None,
+) -> dict[str, Any] | None:
     from langgraph_api.state import runnable_config_to_checkpoint
 
     if not payload:
         return None
 
-    payload["checkpoint"] = runnable_config_to_checkpoint(payload["config"])
-    payload["parent_checkpoint"] = runnable_config_to_checkpoint(
-        payload["parent_config"] if "parent_config" in payload else None
-    )
-
-    payload["tasks"] = [_preproces_debug_checkpoint_task(t) for t in payload["tasks"]]
-
     # TODO: deprecate the `config`` and `parent_config`` fields
-    return payload
+    return {
+        **payload,
+        "checkpoint": runnable_config_to_checkpoint(payload["config"]),
+        "parent_checkpoint": runnable_config_to_checkpoint(
+            payload.get("parent_config", None)
+        ),
+        "tasks": [_preproces_debug_checkpoint_task(t) for t in payload["tasks"]],
+    }
 
 
 @asynccontextmanager
@@ -121,7 +125,7 @@ async def astream_state(
     attempt: int,
     done: ValueEvent,
     *,
-    on_checkpoint: Callable[[CheckpointPayload], None] = lambda _: None,
+    on_checkpoint: Callable[[CheckpointPayload | None], None] = lambda _: None,
     on_task_result: Callable[[TaskResultPayload], None] = lambda _: None,
 ) -> AnyStream:
     """Stream messages from the runnable."""
@@ -133,11 +137,12 @@ async def astream_state(
     subgraphs = kwargs.get("subgraphs", False)
     temporary = kwargs.pop("temporary", False)
     context = kwargs.pop("context", None)
-    config = kwargs.pop("config")
+    config = cast(RunnableConfig, kwargs.pop("config"))
+    configurable = config["configurable"]
     stack = AsyncExitStack()
     graph = await stack.enter_async_context(
         get_graph(
-            config["configurable"]["graph_id"],
+            configurable["graph_id"],
             config,
             store=(await api_store.get_store()),
             checkpointer=None if temporary else Checkpointer(),
@@ -168,6 +173,8 @@ async def astream_state(
     if "updates" not in stream_modes_set:
         stream_modes_set.add("updates")
         only_interrupt_updates = True
+    else:
+        only_interrupt_updates = False
     # attach attempt metadata
     config["metadata"]["run_attempt"] = attempt
     # attach langgraph metadata
@@ -179,7 +186,7 @@ async def astream_state(
     # attach node counter
     is_remote_pregel = isinstance(graph, BaseRemotePregel)
     if not is_remote_pregel:
-        config["configurable"]["__pregel_node_finished"] = incr_nodes
+        configurable["__pregel_node_finished"] = incr_nodes
 
     # attach run_id to config
     # for attempts beyond the first, use a fresh, unique run_id
@@ -192,9 +199,9 @@ async def astream_state(
     yield "metadata", {"run_id": run_id, "attempt": attempt}
 
     #  is a langsmith tracing project is specified, additionally pass that in to tracing context
-    if ls_project := config["configurable"].get("__langsmith_project__"):
+    if ls_project := configurable.get("__langsmith_project__"):
         updates = None
-        if example_id := config["configurable"].get("__langsmith_example_id__"):
+        if example_id := configurable.get("__langsmith_example_id__"):
             updates = {"reference_example_id": example_id}
 
         await stack.enter_async_context(
@@ -216,7 +223,7 @@ async def astream_state(
     if use_astream_events:
         async with (
             stack,
-            aclosing(
+            aclosing(  # type: ignore[invalid-argument-type]
                 graph.astream_events(
                     input,
                     config,
@@ -231,15 +238,21 @@ async def astream_state(
                 event = await wait_if_not_done(anext(stream, sentinel), done)
                 if event is sentinel:
                     break
+                event = cast(dict, event)
                 if event.get("tags") and "langsmith:hidden" in event["tags"]:
                     continue
-                if "messages" in stream_mode and isinstance(graph, BaseRemotePregel):
-                    if event["event"] == "on_custom_event" and event["name"] in (
+                if (
+                    "messages" in stream_mode
+                    and isinstance(graph, BaseRemotePregel)
+                    and event["event"] == "on_custom_event"
+                    and event["name"]
+                    in (
                         "messages/complete",
                         "messages/partial",
                         "messages/metadata",
-                    ):
-                        yield event["name"], event["data"]
+                    )
+                ):
+                    yield event["name"], event["data"]
                 # TODO support messages-tuple for js graphs
                 if event["event"] == "on_chain_stream" and event["run_id"] == run_id:
                     if subgraphs:
@@ -251,6 +264,7 @@ async def astream_state(
                     if mode == "debug":
                         if chunk["type"] == "checkpoint":
                             checkpoint = _preprocess_debug_checkpoint(chunk["payload"])
+                            chunk["payload"] = checkpoint
                             on_checkpoint(checkpoint)
                         elif chunk["type"] == "task_result":
                             on_task_result(chunk["payload"])
@@ -261,11 +275,14 @@ async def astream_state(
                             else:
                                 yield "messages", chunk
                         else:
-                            msg, meta = cast(
+                            msg_, meta = cast(
                                 tuple[BaseMessage | dict, dict[str, Any]], chunk
                             )
-                            if isinstance(msg, dict):
-                                msg = convert_to_messages([msg])[0]
+                            msg = (
+                                convert_to_messages([msg_])[0]
+                                if isinstance(msg_, dict)
+                                else cast(BaseMessage, msg_)
+                            )
                             if msg.id in messages:
                                 messages[msg.id] += msg
                             else:
@@ -323,14 +340,15 @@ async def astream_state(
                 if event is sentinel:
                     break
                 if subgraphs:
-                    ns, mode, chunk = event
+                    ns, mode, chunk = cast(tuple[str, str, dict[str, Any]], event)
                 else:
-                    mode, chunk = event
+                    mode, chunk = cast(tuple[str, dict[str, Any]], event)
                     ns = None
                 # --- begin shared logic with astream_events ---
                 if mode == "debug":
                     if chunk["type"] == "checkpoint":
                         checkpoint = _preprocess_debug_checkpoint(chunk["payload"])
+                        chunk["payload"] = checkpoint
                         on_checkpoint(checkpoint)
                     elif chunk["type"] == "task_result":
                         on_task_result(chunk["payload"])
@@ -341,11 +359,15 @@ async def astream_state(
                         else:
                             yield "messages", chunk
                     else:
-                        msg, meta = cast(
+                        msg_, meta = cast(
                             tuple[BaseMessage | dict, dict[str, Any]], chunk
                         )
-                        if isinstance(msg, dict):
-                            msg = convert_to_messages([msg])[0]
+                        msg = (
+                            convert_to_messages([msg_])[0]
+                            if isinstance(msg_, dict)
+                            else cast(BaseMessage, msg_)
+                        )
+
                         if msg.id in messages:
                             messages[msg.id] += msg
                         else:
@@ -399,7 +421,7 @@ async def astream_state(
 
 async def consume(
     stream: AnyStream,
-    run_id: str,
+    run_id: str | uuid.UUID,
     resumable: bool = False,
     stream_modes: set[StreamMode] | None = None,
 ) -> None:
@@ -408,7 +430,7 @@ async def consume(
         stream_modes.add("messages")
     stream_modes.add("metadata")
 
-    async with aclosing(stream):
+    async with aclosing(stream):  # type: ignore[invalid-argument-type]
         try:
             async for mode, payload in stream:
                 await Runs.Stream.publish(
